///////////////////////////////////////////////////////////////////////////////////////////
//                                                   41 Post                             //
// Android: loading images from a remote location, SD card and from the Resources folder //
// Created by DimasTheDriver in 25/Jan/2011                                      		 //
// Availiable at:       http://www.41post.com/?p=2744                           		 //
///////////////////////////////////////////////////////////////////////////////////////////

package fortyonepost.com.cv;

import java.io.File;

import android.content.Context;
import android.content.res.Resources;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.graphics.Canvas;
import android.graphics.Color;
import android.graphics.Paint;
import android.view.View;

public class CustomView extends View
{
	//create this object to have access to the application's resources
	private Resources res;
	//creates an empty bitmap
	private Bitmap resBMP;
	//creates an empty Bitmap that will be used to display the image from the SD card
	public Bitmap sdcardBMP;
	//creates a default paint
	private Paint defPaint = new Paint();
	//creates a paint for text
	private Paint textPaint = new Paint();

	//as we inherit the View class, it is necessary to add this constructor 
	public CustomView(Context context) 
	{
		super(context);

        //creates a context handler, to link the resource folder to the application context
        res = context.getResources();
        
        //loads the bitmap that is inside the res/drawable/folder
        resBMP = BitmapFactory.decodeResource(res, R.drawable.smiley);
        
        sdcardBMP = LoadBMPsdcard("/sdcard/cardimage.gif");

        //sets the textPaint parameters, such as color and anti-aliasing 
        textPaint.setColor(Color.rgb(55, 97, 128));
        textPaint.setAntiAlias(true);
	}
	
	//this method loads the bitmap from the memory card
	private Bitmap LoadBMPsdcard(String path)
	{
		//creates a 'File' object, to check if the image exists (Thanks to Jbeerdev for the tip)
		File imageFile = new File(path);
		
		//if the file exists
		if(imageFile.exists())
		{
			//load the bitmap from the given path
			return BitmapFactory.decodeFile(path);
		}
		else
		{
			//return the standard 'Image not found' bitmap
			return BitmapFactory.decodeResource(getResources(), R.drawable.imagenotfound);
		}
	}
	
	//Override this method to render elements on the screen using the Canvas
	@Override
	protected void onDraw(Canvas canvas) 
	{
		//sets the background color to cyan using hex ARGB values
		canvas.drawColor(0xFF00FFFF); //same as: canvas.drawColor(Color.CYAN);
		
		//render the first line of text
		canvas.drawText("This image was loaded from the Res/drawable folder:", 10, 25, textPaint);

		//render the resBMP bitmap at the specified position
		canvas.drawBitmap(resBMP, 88, 35, defPaint);
		
		//render the second line of text
		canvas.drawText("This image loads from the SD card:", 10, 145, textPaint);

		//render the SD card image
		canvas.drawBitmap(sdcardBMP, 88, 155, null);
		
		//render the third line of text
		canvas.drawText("This image loads from a remote location:", 10, 265, textPaint);
		
		//render the downloaded bitmap from the CanvasExample class
		canvas.drawBitmap(((CanvasExample)getContext()).downloadedBitmap, 88, 275, defPaint);
		
		
		
		//the parent onDraw() method.
		super.onDraw(canvas);
	}
}
